@@ -18,7 +18,7 @@ prefix=/usr/local
 if [ -e ${prefix}/share/kea/scripts/admin-utils.sh ]; then
     . ${prefix}/share/kea/scripts/admin-utils.sh
 else
-    . /pobj/kea-1.7.8-postgresql/kea-1.7.8/src/bin/admin/admin-utils.sh
+    . /usr/ports/pobj/kea-1.8.2-postgresql/kea-1.8.2/src/bin/admin/admin-utils.sh
 fi
 
 # First argument is must be the expected schema version <major>.<minor>
